==> dnacentersdk-2.4.0.tar.gz: dnacentersdk-2.4.0/dnacentersdk/models/validators/v2_2_2_3/jsd_b7079a38844e56dd8f1b6b876880a02e.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center AddMulticastInSDAFabric data model.

Copyright (c) 2019-2021 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import fastjsonschema
import json
from dnacentersdk.exceptions import MalformedRequest

from builtins import *


class JSONSchemaValidatorB7079A38844E56Dd8F1B6B876880A02E(object):
    """AddMulticastInSDAFabric request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorB7079A38844E56Dd8F1B6B876880A02E, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "fabricSiteNameHierarchy": {
                "type": "string"
                },
                "multicastMethod": {
                "enum": [
                "native_multicast",
                ""
                ],
                "type": "string"
                },
                "multicastVnInfo": {
                "properties": {
                "externalRpIpAddress": {
                "type": "string"
                },
                "ipPoolName": {
                "type": "string"
                },
                "ssmGroupRange": {
                "type": "string"
                },
                "ssmInfo": {
                "type": "object"
                },
                "ssmWildcardMask": {
                "type": "string"
                },
                "virtualNetworkName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "muticastType": {
                "enum": [
                "ssm",
                "asm_with_external_rp",
                ""
                ],
                "type": "string"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> dnacentersdk-2.5.3.tar.gz: dnacentersdk-2.5.3/dnacentersdk/models/validators/v2_3_3_0/jsd_b7079a38844e56dd8f1b6b876880a02e.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center AddMulticastInSDAFabric data model.

Copyright (c) 2019-2021 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema

from dnacentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorB7079A38844E56Dd8F1B6B876880A02E(object):
    """AddMulticastInSDAFabric request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorB7079A38844E56Dd8F1B6B876880A02E, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "multicastMethod": {
                
                "type": "string"
                },
                "multicastType": {
                "enum": [
                "ssm",
                "asm_with_internal_rp",
                "asm_with_external_rp"
                ],
                "type": "string"
                },
                "multicastVnInfo": {
                "items": {
                "properties": {
                "externalRpIpAddress": {
                "type": "string"
                },
                "internalRpIpAddress": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "ipPoolName": {
                "type": "string"
                },
                "ssmInfo": {
                "properties": {
                "ssmGroupRange": {
                "type": "string"
                },
                "ssmWildcardMask": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "virtualNetworkName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "siteNameHierarchy": {
                "type": "string"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )
